@@ -100,8 +100,8 @@ static void	    miSpriteComputeSaved(ScreenPtr pScreen);
   ((pScreen)->field = \
    ((miSpriteScreenPtr) (pScreen)->devPrivates[miSpriteScreenIndex].ptr)->field)
 
-#define SCREEN_EPILOGUE(pScreen, field, wrapper)\
-    ((pScreen)->field = wrapper)
+#define SCREEN_EPILOGUE(pScreen, field)\
+    ((pScreen)->field = miSprite##field)
 
 /*
  * pointer-sprite method table
@@ -113,7 +113,7 @@ static void miSpriteSetCursor(ScreenPtr pScreen, CursorPtr pCursor,
 			      int x, int y);
 static void miSpriteMoveCursor(ScreenPtr pScreen, int x, int y);
 
-miPointerSpriteFuncRec miSpritePointerFuncs = {
+_X_EXPORT miPointerSpriteFuncRec miSpritePointerFuncs = {
     miSpriteRealizeCursor,
     miSpriteUnrealizeCursor,
     miSpriteSetCursor,
@@ -301,7 +301,7 @@ miSpriteGetImage (pDrawable, sx, sy, w, h, format, planemask, pdstLine)
     (*pScreen->GetImage) (pDrawable, sx, sy, w, h,
 			  format, planemask, pdstLine);
 
-    SCREEN_EPILOGUE (pScreen, GetImage, miSpriteGetImage);
+    SCREEN_EPILOGUE (pScreen, GetImage);
 }
 
 static void
@@ -347,7 +347,7 @@ miSpriteGetSpans (pDrawable, wMax, ppt, pwidth, nspans, pdstStart)
 
     (*pScreen->GetSpans) (pDrawable, wMax, ppt, pwidth, nspans, pdstStart);
 
-    SCREEN_EPILOGUE (pScreen, GetSpans, miSpriteGetSpans);
+    SCREEN_EPILOGUE (pScreen, GetSpans);
 }
 
 static void
@@ -373,7 +373,7 @@ miSpriteSourceValidate (pDrawable, x, y, width, height)
     if (pScreen->SourceValidate)
 	(*pScreen->SourceValidate) (pDrawable, x, y, width, height);
 
-    SCREEN_EPILOGUE (pScreen, SourceValidate, miSpriteSourceValidate);
+    SCREEN_EPILOGUE (pScreen, SourceValidate);
 }
 
 static void
@@ -396,7 +396,7 @@ miSpriteCopyWindow (WindowPtr pWindow, DDXPointRec ptOldOrg, RegionPtr prgnSrc)
     }
 
     (*pScreen->CopyWindow) (pWindow, ptOldOrg, prgnSrc);
-    SCREEN_EPILOGUE (pScreen, CopyWindow, miSpriteCopyWindow);
+    SCREEN_EPILOGUE (pScreen, CopyWindow);
 }
 
 static void
@@ -415,7 +415,7 @@ miSpriteBlockHandler (i, blockData, pTimeout, pReadmask)
     
     (*pScreen->BlockHandler) (i, blockData, pTimeout, pReadmask);
 
-    SCREEN_EPILOGUE(pScreen, BlockHandler, miSpriteBlockHandler);
+    SCREEN_EPILOGUE(pScreen, BlockHandler);
 
     if (!pPriv->isUp && pPriv->shouldBeUp)
     {
@@ -437,7 +437,7 @@ miSpriteInstallColormap (pMap)
     
     (*pScreen->InstallColormap) (pMap);
 
-    SCREEN_EPILOGUE(pScreen, InstallColormap, miSpriteInstallColormap);
+    SCREEN_EPILOGUE(pScreen, InstallColormap);
 
     pPriv->pInstalledMap = pMap;
     if (pPriv->pColormap != pMap)
@@ -466,7 +466,7 @@ miSpriteStoreColors (pMap, ndef, pdef)
     
     (*pScreen->StoreColors) (pMap, ndef, pdef);
 
-    SCREEN_EPILOGUE(pScreen, StoreColors, miSpriteStoreColors);
+    SCREEN_EPILOGUE(pScreen, StoreColors);
 
     if (pPriv->pColormap == pMap)
     {
@@ -595,7 +595,7 @@ miSpriteSaveDoomedAreas (pWin, pObscured, dx, dy)
 
     (*pScreen->SaveDoomedAreas) (pWin, pObscured, dx, dy);
 
-    SCREEN_EPILOGUE (pScreen, SaveDoomedAreas, miSpriteSaveDoomedAreas);
+    SCREEN_EPILOGUE (pScreen, SaveDoomedAreas);
 }
 
 /*
